@@ -2,14 +2,15 @@
 
 use Geo::IP;
 
-my $gi = Geo::IP->open("/var/db/GeoIP/GeoIPv6.dat", GEOIP_STANDARD);
+my $gi
+    = Geo::IP->open( "/var/db/GeoIP/GeoIPv6.dat", GEOIP_STANDARD );
 
 die "Please install the CAPI for IPv6 support\n" unless $gi->api eq 'CAPI';
 
 while (<DATA>) {
-  chomp;
-  my ($cc) = $gi->country_code_by_addr_v6($_) || '';
-  print join("\t",$_,$cc) . "\n";
+    chomp;
+    my ($cc) = $gi->country_code_by_addr_v6($_) || '';
+    print join( "\t", $_, $cc ) . "\n";
 }
 
 __DATA__
